request_filters
================

...

Quick start
-----------

1. Add 'request_filters' to your INSTALLED_APPS setting like this:

   ```
   INSTALLED_APPS = [
   ...,
   'request_filters',
   ]
   ```

2. ...